==> edge-login-ui-rn-2.18.0.tgz: package/lib/components/scenes/newAccount/NewAccountReviewScene.js <==
import * as React from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { completeLogin } from '../../../actions/LoginCompleteActions';
import { lstrings } from '../../../common/locales/strings';
import { useHandler } from '../../../hooks/useHandler';
import { useImports } from '../../../hooks/useImports';
import { useDispatch } from '../../../types/ReduxTypes';
import { useTheme } from '../../services/ThemeContext';
import { AccountInfo } from '../../themed/AccountInfo';
import { EdgeText } from '../../themed/EdgeText';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const AccountReviewComponent = (props) => {
    const { username, password, pin, onNext } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(ThemedScene, { title: lstrings.review },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, lstrings.tap_to_review_button),
            React.createElement(FormError, { marginRem: [0, 0, 2], title: lstrings.alert_dropdown_warning, numberOfLines: 2, isWarning: true }, lstrings.warning_message),
            React.createElement(AccountInfo, { marginRem: [0, 2.5], username: username, password: password, pin: pin }),
            React.createElement(View, { style: styles.actions },
                React.createElement(MainButton, { label: lstrings.create, type: "secondary", onPress: onNext })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(1.5)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(2)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(5),
        minHeight: theme.rem(3)
    }
}));
export const NewAccountReviewScene = (props) => {
    const { route } = props;
    const { onLogEvent = (event, values) => { } } = useImports();
    const dispatch = useDispatch();
    const handleNext = useHandler(() => {
        onLogEvent(`Signup_Review_Done`);
        dispatch(completeLogin(route.params.account));
    });
    return React.createElement(AccountReviewComponent, Object.assign({}, route.params, { onNext: handleNext }));
};
export const UpgradeReviewScene = (props) => {
    const { route } = props;
    const { onComplete, onLogEvent = (event, values) => { } } = useImports();
    const handleNext = useHandler(() => {
        onLogEvent(`Backup_Review_Done`);
        if (onComplete != null)
            onComplete();
    });
    return React.createElement(AccountReviewComponent, Object.assign({}, route.params, { onNext: handleNext }));
};

==> edge-login-ui-rn-2.20.0.tgz: package/lib/components/scenes/newAccount/NewAccountReviewScene.js <==
import * as React from 'react';
import { ScrollView } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { completeLogin } from '../../../actions/LoginCompleteActions';
import { lstrings } from '../../../common/locales/strings';
import { useHandler } from '../../../hooks/useHandler';
import { useImports } from '../../../hooks/useImports';
import { useDispatch } from '../../../types/ReduxTypes';
import { EdgeAnim } from '../../common/EdgeAnim';
import { useTheme } from '../../services/ThemeContext';
import { AccountInfo } from '../../themed/AccountInfo';
import { EdgeText } from '../../themed/EdgeText';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const AccountReviewComponent = (props) => {
    const { username, password, pin, onNext } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(ThemedScene, { title: lstrings.review },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            React.createElement(EdgeAnim, { enter: { type: 'fadeInUp', distance: 60 } },
                React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, lstrings.tap_to_review_button)),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInUp', distance: 40 } },
                React.createElement(FormError, { marginRem: [0, 0, 2], title: lstrings.alert_dropdown_warning, numberOfLines: 2, isWarning: true }, lstrings.warning_message)),
            React.createElement(EdgeAnim, { enter: { type: 'fadeInDown', distance: 40 } },
                React.createElement(AccountInfo, { marginRem: [0, 2.5], username: username, password: password, pin: pin })),
            React.createElement(EdgeAnim, { style: styles.actions, enter: { type: 'fadeInDown', distance: 60 } },
                React.createElement(MainButton, { label: lstrings.create, type: "secondary", onPress: onNext })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(1.5)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(2)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(5),
        minHeight: theme.rem(3)
    }
}));
export const NewAccountReviewScene = (props) => {
    const { route } = props;
    const { onLogEvent = (event, values) => { } } = useImports();
    const dispatch = useDispatch();
    const handleNext = useHandler(() => {
        onLogEvent(`Signup_Review_Done`);
        dispatch(completeLogin(route.params.account));
    });
    return React.createElement(AccountReviewComponent, Object.assign({}, route.params, { onNext: handleNext }));
};
export const UpgradeReviewScene = (props) => {
    const { route } = props;
    const { onComplete, onLogEvent = (event, values) => { } } = useImports();
    const handleNext = useHandler(() => {
        onLogEvent(`Backup_Review_Done`);
        if (onComplete != null)
            onComplete();
    });
    return React.createElement(AccountReviewComponent, Object.assign({}, route.params, { onNext: handleNext }));
};
